;; Generated package description from spacious-padding.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "spacious-padding" "0.8.0.0.20260724.4" "Increase the padding/spacing of frames and windows" '((emacs "28.1")) :commit "03d475863f65fafe502141a06e919bc057554991" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :keywords '("convenience" "focus" "writing" "presentation") :url "https://github.com/protesilaos/spacious-padding")
